@@ -11,7 +11,17 @@ Use the nosetests script (after installation by setuptools)::
 
   nosetests [options] [(optional) test files or directories]
 
-You may also use nose in a test script::
+In addition to passing command-line options, you may also put configuration
+options in a .noserc or nose.cfg file in your home directory. These are
+standard .ini-style config files. Put your nosetests configuration in a
+[nosetests] section, with the -- prefix removed::
+
+ [nosetests]
+ verbosity=3
+ with-doctest 
+  
+There are several other ways to use the nose test runner besides the
+`nosetests` script. You may use nose in a test script::
 
   import nose
   nose.main()
@@ -27,11 +37,11 @@ or raised an uncaught exception. Lastly, you can run nose.core directly, which
 will run nose.main()::
 
   python /path/to/nose/core.py
-
+  
 Please see the usage message for the nosetests script for information
 about how to control which tests nose runs, which plugins are loaded,
 and the test output.
-  
+ 
 Features
 --------
 
@@ -236,6 +246,10 @@ or by direct assignment::
   test.setup = setup_func
   test.teardown = teardown_func
   
+Please note that `with_setup` is useful *only* for test functions, not for
+test methods in TestCase subclasses or other test classes. For those cases,
+define `setUp` and `tearDown` methods in the class.
+  
 Test generators
 ===============
 
@@ -371,7 +385,7 @@ from nose.tools import with_setup # backwards compatibility
 from nose.util import file_like, split_test_name, test_address
 
 __author__ = 'Jason Pellerin'
-__versioninfo__ = (0, 9, 2)
+__versioninfo__ = (0, 9, 3)
 __version__ = '.'.join(map(str, __versioninfo__))
 
 __all__ = [ 
