@@ -96,20 +96,26 @@ class Doctest(Plugin):
         if not self.matches(module.__name__):
             log.debug("Doctest doesn't want module %s", module)
             return
-        try:
-            doctests = doctest.DocTestSuite(module)
-        except ValueError:
-            log.debug("No doctests in %s", module)
+        doctests = self._loadDoctests(module)
+        if not doctests:
             return
+        # < 2.4 doctest (and unittest) suites don't have iterators
+        log.debug("Doctests found in %s", module)
+        if hasattr(doctests, '__iter__'):
+            doctest_suite = doctests
         else:
-            # < 2.4 doctest (and unittest) suites don't have iterators
-            log.debug("Doctests found in %s", module)
-            if hasattr(doctests, '__iter__'):
-                doctest_suite = doctests
-            else:
-                doctest_suite = doctests._tests
-            for test in doctest_suite:
-                yield test
+            doctest_suite = doctests._tests
+        for test in doctest_suite:
+            yield test
+
+    def _loadDoctests(self, module):
+        try:            
+            return doctest.DocTestSuite(module)
+        except ValueError, e:
+            # empty = ValueError
+            if 'has no tests' in e:
+                return
+            raise            
             
     def loadTestsFromPath(self, filename, package=None, importPath=None):
         if self.extension and anyp(filename.endswith, self.extension):
@@ -146,8 +152,10 @@ class Doctest(Plugin):
         # also want files that match my extension
         if (self.extension
             and anyp(file.endswith, self.extension)
-            and (self.conf.exclude is None
-                 or not self.conf.exclude.search(file))):
+            and (not self.conf.exclude
+                 or not filter(None, 
+                               [exc.search(file)
+                                for exc in self.conf.exclude]))):
             return True
         return None
         
