@@ -61,6 +61,9 @@ class TestBuiltinPlugins(unittest.TestCase):
     def test_failing_load(self):
         tmp = nose.plugins.pkg_resources
         nose.plugins.pkg_resources = ErrPkgResources()
+        class Dummy:
+            pass
+        nose.plugins.Plugin = Dummy
         try:
             # turn off warnings
             filterwarnings('ignore', category=RuntimeWarning)
@@ -68,6 +71,7 @@ class TestBuiltinPlugins(unittest.TestCase):
             self.assertEqual(plugs, [])
         finally:
             nose.plugins.pkg_resources = tmp
+            nose.plugins.Plugin = Plugin
             resetwarnings()
             
     def test_add_options(self):
@@ -452,8 +456,11 @@ class TestProfPlugin(unittest.TestCase):
     def test_begin(self):
         plug = Profile()
         plug.pfile = tempfile.mkstemp()[1]
-        plug.begin()
-        assert plug.prof
+        try:
+            plug.begin()
+            assert plug.prof
+        finally:
+            plug.finalize(None)
 
     def test_prepare_test(self):
         r = {}
@@ -466,8 +473,25 @@ class TestProfPlugin(unittest.TestCase):
         plug = Profile()
         plug.prof = dummy()
         result = plug.prepareTest(func)
-        result(r)
-        assert r[1] == ("func", "wrapped")
-        
+        try:
+            result(r)
+            assert r[1] == ("func", "wrapped")
+        finally:
+            plug.finalize(None)
+
+    def test_finalize(self):
+        def func():
+            pass
+
+        plug = Profile()
+        plug.begin()
+        plug.prepareTest(func)
+        pfile = plug.pfile
+        try:
+            assert os.path.exists(pfile)
+        finally:
+            plug.finalize(None)
+        assert not os.path.exists(pfile)
+
 if __name__ == '__main__':
     unittest.main()
